.. Copyright (c) 2016, Johan Mabille, Sylvain Corlay 

   Distributed under the terms of the BSD 3-Clause License.

   The full license is in the file LICENSE, distributed with this software.

simd_batch_bool
===============

.. doxygenclass:: xsimd::simd_batch_bool
   :project: xsimd
   :members:

Bitwise operators
-----------------

.. doxygengroup:: simd_batch_bool_bitwise
   :project: xsimd
   :content-only:

Logical operators
-----------------

.. doxygengroup:: simd_batch_bool_logical
   :project: xsimd
   :content-only:

Comparison operators
--------------------

.. doxygengroup:: simd_batch_bool_comparison
   :project: xsimd
   :content-only:
   
Reducers
--------

.. doxygengroup:: simd_batch_bool_reducers
   :project: xsimd
   :content-only:

